import { MessageService, CommandContribution, CommandRegistry, Command, DisposableCollection } from '@devpodio/core/lib/common';
import { FrontendApplicationContribution } from '@devpodio/core/lib/browser';
import { Workspace, Languages } from '@devpodio/languages/lib/browser';
import { WorkspaceService } from '@devpodio/workspace/lib/browser';
import { DebugConfiguration } from '@devpodio/debug/lib/common/debug-common';
import { DebugSession } from '@devpodio/debug/lib/browser/debug-session';
import { DebugSessionManager } from '@devpodio/debug/lib/browser/debug-session-manager';
import { DebugConfigurationManager } from '@devpodio/debug/lib/browser/debug-configuration-manager';
import { JavaDebugPreferences } from './java-debug-preferences';
declare enum HcrChangeType {
    ERROR = "ERROR",
    WARNING = "WARNING",
    STARTING = "STARTING",
    END = "END",
    BUILD_COMPLETE = "BUILD_COMPLETE"
}
export declare namespace JavaDebugCommands {
    const RUN: Command;
    const DEBUG: Command;
    const RESOLVE_MAIN_METHOD = "vscode.java.resolveMainMethod";
}
export declare namespace JavaDebugSession {
    function is(session: DebugSession): boolean;
}
export declare class JavaDebugFrontendContribution implements FrontendApplicationContribution, CommandContribution {
    protected readonly workspace: Workspace;
    protected readonly languages: Languages;
    protected readonly commands: CommandRegistry;
    protected readonly messages: MessageService;
    protected readonly sessions: DebugSessionManager;
    protected readonly preferences: JavaDebugPreferences;
    protected readonly workspaceService: WorkspaceService;
    protected readonly configurations: DebugConfigurationManager;
    protected readonly suppressedReasons: Set<string>;
    initialize(): void;
    registerCommands(commands: CommandRegistry): void;
    protected readonly toDisposeRunDebugCodeLens: DisposableCollection;
    protected updateRunDebugCodeLens(): void;
    protected runProgram(mainClass: string, projectName: string, uri: string, noDebug?: boolean): Promise<void>;
    protected constructDebugConfig(mainClass: string, projectName: string, workspaceFolderUri?: string): DebugConfiguration;
    protected findConfiguration(mainClass: string, projectName: string): IterableIterator<DebugConfiguration>;
    protected dirtyDebugSettings: boolean;
    protected updateDebugSettings(): Promise<void>;
    protected convertLogLevel(commonLogLevel: string): "FINE" | "WARNING" | "SEVERE" | "INFO";
    protected applyCodeChanges(session: DebugSession, { changeType, message }: {
        changeType?: HcrChangeType;
        message: string;
    }): Promise<void>;
    protected handleUserNotification({ notificationType, message }: {
        notificationType?: string;
        message: string;
    }): Promise<void>;
}
export {};
