import { DebugConfiguration } from '@devpodio/debug/lib/common/debug-configuration';
import { JavaExtensionContribution } from '@devpodio/java/lib/node';
import { MessageService, CommandService } from '@devpodio/core/lib/common';
import { QuickPickService, QuickPickItem } from '@devpodio/core/lib/common/quick-pick-service';
import { AbstractVSCodeDebugAdapterContribution } from '@devpodio/debug/lib/node/vscode/vscode-debug-adapter-contribution';
export declare namespace VSCodeJavaDebugCommands {
    const COMPILE_WORKSPACE = "java.workspace.compile";
    const RESOLVE_MAINCLASS = "vscode.java.resolveMainClass";
    const VALIDATE_LAUNCH_CONFIG = "vscode.java.validateLaunchConfig";
    const RESOLVE_CLASSPATH = "vscode.java.resolveClasspath";
    const START_DEBUG_SESSION = "vscode.java.startDebugSession";
}
export interface MainClassOption {
    readonly mainClass: string;
    readonly projectName?: string;
    readonly filePath?: string;
}
interface ValidationResult {
    readonly isValid: boolean;
    readonly message?: string;
}
interface LaunchValidationResponse {
    readonly mainClass: ValidationResult;
    readonly projectName: ValidationResult;
    readonly proposals?: MainClassOption[];
}
export declare class JavaDebugExtensionContribution extends AbstractVSCodeDebugAdapterContribution implements JavaExtensionContribution {
    constructor();
    getExtensionBundles(): Promise<string[]>;
}
export declare class JavaDebugAdapterContribution extends JavaDebugExtensionContribution {
    protected readonly commands: CommandService;
    protected readonly messages: MessageService;
    protected readonly quickPickService: QuickPickService;
    provideDebugConfigurations(workspaceFolderUri?: string): Promise<DebugConfiguration[]>;
    protected constructLaunchConfigName(mainClass: string, projectName: string | undefined, cache: {
        [name: string]: number;
    }): string;
    resolveDebugConfiguration(config: DebugConfiguration, workspaceFolderUri?: string): Promise<DebugConfiguration | undefined>;
    protected resolveLaunchConfig(config: DebugConfiguration, workspaceFolderUri?: string): Promise<MainClassOption | undefined>;
    protected promptMainClass(workspaceFolderUri?: string): Promise<MainClassOption | undefined>;
    protected fixMainClass(config: DebugConfiguration, validationResponse: LaunchValidationResponse, workspaceFolderUri?: string): Promise<MainClassOption | undefined>;
    protected selectMainClass(options: MainClassOption[]): Promise<MainClassOption | undefined>;
    protected formatMainClassOptions(options: MainClassOption[]): QuickPickItem<MainClassOption>[];
    protected resolveMainClass(workspaceFolderUri?: string): Promise<MainClassOption[]>;
    protected compileWorkspace(): Promise<void>;
    protected validateLaunchConfig(mainClass: string, projectName: string, containsExternalClasspaths: boolean, workspaceFolderUri?: string): Promise<LaunchValidationResponse | undefined>;
    protected resolveClasspath(mainClass: string | undefined, projectName: string | undefined): Promise<[string, string] | undefined>;
    protected startDebugSession(): Promise<any>;
    protected concatArgs(args: any[]): string;
}
export {};
